%  function [tf,f]=table_ismember(table1,table2,keys1,keys2,NaNisequal)   
%  table_ismember - find location of rows of table1 in rows of table2   
%   
%  CALL:   
%   [tf,f]=table_ismember(table1,table2)   
%   [tf,f]=table_ismember(table1,table2,NaNisequal)   
%   [tf,f]=table_ismember(table1,table2,keys1)   
%   [tf,f]=table_ismember(table1,table2,keys1,NaNisequal)   
%   [tf,f]=table_ismember(table1,table2,keys1,keys2)   
%   [tf,f]=table_ismember(table1,table2,keys1,keys,NaNisequal)   
%   
%  INPUT:   
%    table1:   
%          first structure of arrays (tablestructure)   
%          +----fld1(N1,:)   
%          +----fld2(N1,:)   
%    table2:   
%          second structure of arrays (tablestructure)   
%          +----fld1(N2,:)   
%          +----fld2(N2,:)   
%    keys1,keys:   
%          cell array of column names.   
%          keys1 must be columns of table1 and keys2 must be columns in   
%          table2.   
%          if keys2 is not specified, it is assumed that keys2=keys1.   
%          columns table.keys1 are compared to columns table.keys2.   
%      NaNisequal:   
%          if true, treat NaN values as equal. Note that "ismember" does   
%          NOT treat NaN's as equal. Defaults to false.   
%   
%  OUTPUT:   
%      tf[N1,1]   
%          boolean vector corresponding to table1.   
%          tf(i)=true indicates row(i) is in table 2   
%      f([N1,1]   
%          table-to-table indices:   
%          0 if not found. Otherwise: corresponding element in table2   
%   
%  REVISIONS:   
%    20200611: checked for use with R2016b strings.   
%    20211116: implement "NaNisequal" correctly. simplify parsing of input   
%              arguments.   
%   
%  See also:   
%      is_in         (deals with vectors)   
%      row_is_in     (deals with rows of a matrix)   
%      is_in_struct  (deals with structures)   
%      is_in_eq      (deals with equidistant time series)   
%      is_in_sort    (deals with sorted time series)   
%      table_ismember   (deals with table structure)   
%      tableunique   (get unique indices of table)   
%      tablefind   
   
   
% © Modelit 2006-2023   
% Matlab release: 2023a   
% Date: 2023/03/24 15:18:56   
